import pandas as pd
import numpy as np

from .Team import Team


class League():
    """League"""

    def __init__(self, season_files: np.array):
        self.games_df = pd.concat(
            (pd.read_csv(f) for f in season_files))
        self.teams = list(map(
            lambda name: Team(name, self.games_df), \
            self.games_df.home_team.unique()))

    def get_team(self, name: str):
        return next((x for x in self.teams if x.name == name), None)

    def get_opponent_winning_percentage_for_team_name(self, team_name: str, season: int):
        team = self.get_team(team_name)
        opponents = team.get_list_of_opponents(season)

        if len(opponents) == 0:
            return 0

        return np.array([
            self.get_team(o).winning_percentage_for_season(season) for o in opponents]) \
            .sum()/len(opponents)

    def print_teams_with_strength_of_schedule(self, season: int):
        for t in self.teams:
            print(self.get_opponent_winning_percentage_for_team_name(t.name, season))



import pandas as pd
import numpy as np


class Team():
    """Team"""

    def __init__(self, name: str, games: pd.DataFrame):
        self.name = name
        self.games_df = games.loc[
            (games.home_team == name) |
            (games.away_team == name)]


    def winning_percentage_for_season(self, season: int):
        """Gives percentage of games won"""

        games = self.games_df.loc[(self.games_df.season == season)]

        home_wins = len(games.loc[
            (games.home_team == self.name) &
            (games.home_score >
            games.away_score)].index)

        away_wins = len(games.loc[
            (games.away_team == self.name) &
            (games.away_score >
            games.home_score)].index)

        total = len(self.games_df.loc[(self.games_df.season == season)].index)

        if total == 0:
            return -1
        return (home_wins + away_wins)/total


    def get_list_of_opponents(self, season: int):

        games = self.games_df.loc[(self.games_df.season == season)]
        if len(games) == 0:
            return []
        print(self.name + " getting list of opponents")
        print(games[['home_team','away_team']])

        return games[['home_team','away_team']] \
            .apply(lambda  x: x[0] if x[1] == self.name else x[1], axis=1) \
            .tolist()
